@@ -533,26 +533,24 @@ class StateForActualGivenExecution(object):
                 with BuildContext(data, is_final=is_final):
                     with deterministic_PRNG():
                         args, kwargs = data.draw(self.search_strategy)
-                    if expected_failure is not None:
-                        text_repr[0] = arg_string(test, args, kwargs)
+                        if expected_failure is not None:
+                            text_repr[0] = arg_string(test, args, kwargs)
 
-                    if print_example:
-                        example = "%s(%s)" % (
-                            test.__name__,
-                            arg_string(test, args, kwargs),
-                        )
-                        try:
-                            ast.parse(example)
-                        except SyntaxError:
-                            data.can_reproduce_example_from_repr = False
-                        report("Falsifying example: %s" % (example,))
-                    elif current_verbosity() >= Verbosity.verbose:
-                        report(
-                            lambda: "Trying example: %s(%s)"
-                            % (test.__name__, arg_string(test, args, kwargs))
-                        )
-
-                    with deterministic_PRNG():
+                        if print_example:
+                            example = "%s(%s)" % (
+                                test.__name__,
+                                arg_string(test, args, kwargs),
+                            )
+                            try:
+                                ast.parse(example)
+                            except SyntaxError:
+                                data.can_reproduce_example_from_repr = False
+                            report("Falsifying example: %s" % (example,))
+                        elif current_verbosity() >= Verbosity.verbose:
+                            report(
+                                lambda: "Trying example: %s(%s)"
+                                % (test.__name__, arg_string(test, args, kwargs))
+                            )
                         return test(*args, **kwargs)
 
         result = self.test_runner(data, run)
@@ -614,11 +612,12 @@ class StateForActualGivenExecution(object):
                 raise StopTest(data.testcounter)
             else:
                 tb = get_trimmed_traceback()
-                data.__expected_traceback = "".join(
+                info = data.extra_information
+                info.__expected_traceback = "".join(
                     traceback.format_exception(type(e), e, tb)
                 )
-                data.__expected_exception = e
-                verbose_report(data.__expected_traceback)
+                info.__expected_exception = e
+                verbose_report(info.__expected_traceback)
 
                 origin = traceback.extract_tb(tb)[-1]
                 filename = origin[0]
@@ -669,17 +668,19 @@ class StateForActualGivenExecution(object):
         flaky = 0
 
         for falsifying_example in self.falsifying_examples:
+            info = falsifying_example.extra_information
+
             ran_example = ConjectureData.for_buffer(falsifying_example.buffer)
             self.__was_flaky = False
-            assert falsifying_example.__expected_exception is not None
+            assert info.__expected_exception is not None
             try:
                 self.execute(
                     ran_example,
                     print_example=True,
                     is_final=True,
                     expected_failure=(
-                        falsifying_example.__expected_exception,
-                        falsifying_example.__expected_traceback,
+                        info.__expected_exception,
+                        info.__expected_traceback,
                     ),
                 )
             except (UnsatisfiedAssumption, StopTest):
